"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    experiment_name: str,
    display_name: str = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an SageMaker experiment. An experiment is a collection of trials that are observed, compared and evaluated as a group. A trial is a set of steps, called trial components, that produce a machine learning model. The goal of an experiment is to determine the components that produce the best model. Multiple trials are performed, each one isolating and measuring the impact of a change to one or more inputs, while keeping the remaining inputs constant. When you use SageMaker Studio or the SageMaker Python SDK, all experiments, trials, and trial components are automatically tracked, logged, and indexed. When you use the Amazon Web Services SDK for Python (Boto), you must use the logging APIs provided by the SDK. You can add tags to experiments, trials, trial components and then use the Search API to search for the tags. To add a description to an experiment, specify the optional Description parameter. To add a description later, or to change the description, call the UpdateExperiment API. To get a list of all your experiments, call the ListExperiments API. To view an experiment's properties, call the DescribeExperiment API. To get a list of all the trials associated with an experiment, call the ListTrials API. To create a trial call the CreateTrial API.

    Args:
        experiment_name(str): The name of the experiment. The name must be unique in your Amazon Web Services account and is not case-sensitive.
        display_name(str, optional): The name of the experiment as displayed. The name doesn't need to be unique. If you don't specify DisplayName, the value in ExperimentName is displayed. Defaults to None.
        description(str, optional): The description of the experiment. Defaults to None.
        tags(List, optional): A list of tags to associate with the experiment. You can use Search API to search on the tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.experiment.create(ctx, experiment_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.experiment.create experiment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_experiment",
        op_kwargs={
            "ExperimentName": experiment_name,
            "DisplayName": display_name,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, experiment_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an SageMaker experiment. All trials associated with the experiment must be deleted first. Use the ListTrials API to get a list of the trials associated with the experiment.

    Args:
        experiment_name(str): The name of the experiment to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.experiment.delete(ctx, experiment_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.experiment.delete experiment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_experiment",
        op_kwargs={"ExperimentName": experiment_name},
    )


async def describe(hub, ctx, experiment_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of an experiment's properties.

    Args:
        experiment_name(str): The name of the experiment to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.experiment.describe(ctx, experiment_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.experiment.describe experiment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_experiment",
        op_kwargs={"ExperimentName": experiment_name},
    )


async def list_all(
    hub,
    ctx,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the experiments in your account. The list can be filtered to show only experiments that were created in a specific time range. The list can be sorted by experiment name or creation time.

    Args:
        created_after(str, optional): A filter that returns only experiments created after the specified time. Defaults to None.
        created_before(str, optional): A filter that returns only experiments created before the specified time. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order. The default value is Descending. Defaults to None.
        next_token(str, optional): If the previous call to ListExperiments didn't return the full set of experiments, the call returns a token for getting the next set of experiments. Defaults to None.
        max_results(int, optional): The maximum number of experiments to return in the response. The default value is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.experiment.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.experiment.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_experiments",
        op_kwargs={
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, experiment_name: str, display_name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds, updates, or removes the description of an experiment. Updates the display name of an experiment.

    Args:
        experiment_name(str): The name of the experiment to update.
        display_name(str, optional): The name of the experiment as displayed. The name doesn't need to be unique. If DisplayName isn't specified, ExperimentName is displayed. Defaults to None.
        description(str, optional): The description of the experiment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.experiment.update(ctx, experiment_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.experiment.update experiment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_experiment",
        op_kwargs={
            "ExperimentName": experiment_name,
            "DisplayName": display_name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, stream_name: str, exclusive_start_tag_key: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags for the specified Kinesis data stream. This operation has a limit of five transactions per second per account.

    Args:
        stream_name(str): The name of the stream.
        exclusive_start_tag_key(str, optional): The key to use as the starting point for the list of tags. If this parameter is set, ListTagsForStream gets all tags that occur after ExclusiveStartTagKey. . Defaults to None.
        limit(int, optional): The number of tags to return. If this number is less than the total number of tags associated with the stream, HasMoreTags is set to true. To list additional tags, set ExclusiveStartTagKey to the last key in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.tags.for_stream.list(ctx, stream_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.tags.for_stream.list stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="list_tags_for_stream",
        op_kwargs={
            "StreamName": stream_name,
            "ExclusiveStartTagKey": exclusive_start_tag_key,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    repository_name: str,
    image_ids: List,
    registry_id: str = None,
    accepted_media_types: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets detailed information for an image. Images are specified with either an imageTag or imageDigest. When an image is pulled, the BatchGetImage API is called once to retrieve the image manifest.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the images to describe. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The repository that contains the images to describe.
        image_ids(List): A list of image ID references that correspond to images to describe. The format of the imageIds reference is imageTag=tag or imageDigest=digest.
        accepted_media_types(List, optional): The accepted media types for the request. Valid values: application/vnd.docker.distribution.manifest.v1+json | application/vnd.docker.distribution.manifest.v2+json | application/vnd.oci.image.manifest.v1+json . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.get_image.batch(ctx, repository_name=value, image_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.get_image.batch repository_name=value, image_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="batch_get_image",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageIds": image_ids,
            "acceptedMediaTypes": accepted_media_types,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, auto_scaling_group_name: str, scheduled_action_name: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified scheduled action.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        scheduled_action_name(str): The name of the action to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.scheduled.action.delete(
                ctx, auto_scaling_group_name=value, scheduled_action_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.scheduled.action.delete auto_scaling_group_name=value, scheduled_action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_scheduled_action",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ScheduledActionName": scheduled_action_name,
        },
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_name: str = None,
    scheduled_action_names: List = None,
    start_time: str = None,
    end_time: str = None,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the scheduled actions that haven't run or that have not reached their end time. To describe the scaling activities for scheduled actions that have already run, call the DescribeScalingActivities API.

    Args:
        auto_scaling_group_name(str, optional): The name of the Auto Scaling group. Defaults to None.
        scheduled_action_names(List, optional): The names of one or more scheduled actions. If you omit this parameter, all scheduled actions are described. If you specify an unknown scheduled action, it is ignored with no error. Array Members: Maximum number of 50 actions. Defaults to None.
        start_time(str, optional): The earliest scheduled start time to return. If scheduled action names are provided, this parameter is ignored. Defaults to None.
        end_time(str, optional): The latest scheduled start time to return. If scheduled action names are provided, this parameter is ignored. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.scheduled.action.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.scheduled.action.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_scheduled_actions",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ScheduledActionNames": scheduled_action_names,
            "StartTime": start_time,
            "EndTime": end_time,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, directory_id: str, group_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified IP access control group with the specified directory.

    Args:
        directory_id(str): The identifier of the directory.
        group_ids(List): The identifiers of one or more IP access control groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.group.associate(
                ctx, directory_id=value, group_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.group.associate directory_id=value, group_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="associate_ip_groups",
        op_kwargs={"DirectoryId": directory_id, "GroupIds": group_ids},
    )


async def create(
    hub,
    ctx,
    group_name: str,
    group_desc: str = None,
    user_rules: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an IP access control group. An IP access control group provides you with the ability to control the IP addresses from which users are allowed to access their WorkSpaces. To specify the CIDR address ranges, add rules to your IP access control group and then associate the group with your directory. You can add rules when you create the group or at any time using AuthorizeIpRules. There is a default IP access control group associated with your directory. If you don't associate an IP access control group with your directory, the default group is used. The default group includes a default rule that allows users to access their WorkSpaces from anywhere. You cannot modify the default IP access control group for your directory.

    Args:
        group_name(str): The name of the group.
        group_desc(str, optional): The description of the group. Defaults to None.
        user_rules(List, optional): The rules to add to the group. Defaults to None.
        tags(List, optional): The tags. Each WorkSpaces resource can have a maximum of 50 tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.group.create(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.group.create group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="create_ip_group",
        op_kwargs={
            "GroupName": group_name,
            "GroupDesc": group_desc,
            "UserRules": user_rules,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified IP access control group. You cannot delete an IP access control group that is associated with a directory.

    Args:
        group_id(str): The identifier of the IP access control group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.group.delete(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.group.delete group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="delete_ip_group",
        op_kwargs={"GroupId": group_id},
    )


async def describe_all(
    hub, ctx, group_ids: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your IP access control groups.

    Args:
        group_ids(List, optional): The identifiers of one or more IP access control groups. Defaults to None.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of items to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_ip_groups",
        op_kwargs={
            "GroupIds": group_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def disassociate(hub, ctx, directory_id: str, group_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified IP access control group from the specified directory.

    Args:
        directory_id(str): The identifier of the directory.
        group_ids(List): The identifiers of one or more IP access control groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.group.disassociate(
                ctx, directory_id=value, group_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.group.disassociate directory_id=value, group_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="disassociate_ip_groups",
        op_kwargs={"DirectoryId": directory_id, "GroupIds": group_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    vpc_id: str,
    client_token: str = None,
    dry_run: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    [IPv6 only] Creates an egress-only internet gateway for your VPC. An egress-only internet gateway is used to enable outbound communication over IPv6 from instances in your VPC to the internet, and prevents hosts outside of your VPC from initiating an IPv6 connection with your instance.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_id(str): The ID of the VPC for which to create the egress-only internet gateway.
        tag_specifications(List, optional): The tags to assign to the egress-only internet gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.egress_only_internet_gateway.create(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.egress_only_internet_gateway.create vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_egress_only_internet_gateway",
        op_kwargs={
            "ClientToken": client_token,
            "DryRun": dry_run,
            "VpcId": vpc_id,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(
    hub, ctx, egress_only_internet_gateway_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an egress-only internet gateway.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        egress_only_internet_gateway_id(str): The ID of the egress-only internet gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.egress_only_internet_gateway.delete(
                ctx, egress_only_internet_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.egress_only_internet_gateway.delete egress_only_internet_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_egress_only_internet_gateway",
        op_kwargs={
            "DryRun": dry_run,
            "EgressOnlyInternetGatewayId": egress_only_internet_gateway_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    egress_only_internet_gateway_ids: List = None,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your egress-only internet gateways.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        egress_only_internet_gateway_ids(List, optional): One or more egress-only internet gateway IDs. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        filters(List, optional): One or more filters.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.egress_only_internet_gateway.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.egress_only_internet_gateway.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_egress_only_internet_gateways",
        op_kwargs={
            "DryRun": dry_run,
            "EgressOnlyInternetGatewayIds": egress_only_internet_gateway_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    notebook_instance_lifecycle_config_name: str,
    on_create: List = None,
    on_start: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a lifecycle configuration that you can associate with a notebook instance. A lifecycle configuration is a collection of shell scripts that run when you create or start a notebook instance. Each lifecycle configuration script has a limit of 16384 characters. The value of the $PATH environment variable that is available to both scripts is /sbin:bin:/usr/sbin:/usr/bin. View CloudWatch Logs for notebook instance lifecycle configurations in log group /aws/sagemaker/NotebookInstances in log stream [notebook-instance-name]/[LifecycleConfigHook]. Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script runs for longer than 5 minutes, it fails and the notebook instance is not created or started. For information about notebook instance lifestyle configurations, see Step 2.1: (Optional) Customize a Notebook Instance.

    Args:
        notebook_instance_lifecycle_config_name(str): The name of the lifecycle configuration.
        on_create(List, optional): A shell script that runs only once, when you create a notebook instance. The shell script must be a base64-encoded string. Defaults to None.
        on_start(List, optional): A shell script that runs every time you start a notebook instance, including when you create the notebook instance. The shell script must be a base64-encoded string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.lifecycle_config.create(
                ctx, notebook_instance_lifecycle_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.lifecycle_config.create notebook_instance_lifecycle_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_notebook_instance_lifecycle_config",
        op_kwargs={
            "NotebookInstanceLifecycleConfigName": notebook_instance_lifecycle_config_name,
            "OnCreate": on_create,
            "OnStart": on_start,
        },
    )


async def delete(hub, ctx, notebook_instance_lifecycle_config_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a notebook instance lifecycle configuration.

    Args:
        notebook_instance_lifecycle_config_name(str): The name of the lifecycle configuration to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.lifecycle_config.delete(
                ctx, notebook_instance_lifecycle_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.lifecycle_config.delete notebook_instance_lifecycle_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_notebook_instance_lifecycle_config",
        op_kwargs={
            "NotebookInstanceLifecycleConfigName": notebook_instance_lifecycle_config_name
        },
    )


async def describe(hub, ctx, notebook_instance_lifecycle_config_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of a notebook instance lifecycle configuration. For information about notebook instance lifestyle configurations, see Step 2.1: (Optional) Customize a Notebook Instance.

    Args:
        notebook_instance_lifecycle_config_name(str): The name of the lifecycle configuration to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.lifecycle_config.describe(
                ctx, notebook_instance_lifecycle_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.lifecycle_config.describe notebook_instance_lifecycle_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_notebook_instance_lifecycle_config",
        op_kwargs={
            "NotebookInstanceLifecycleConfigName": notebook_instance_lifecycle_config_name
        },
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    sort_by: str = None,
    sort_order: str = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
    last_modified_time_before: str = None,
    last_modified_time_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists notebook instance lifestyle configurations created with the CreateNotebookInstanceLifecycleConfig API.

    Args:
        next_token(str, optional): If the result of a ListNotebookInstanceLifecycleConfigs request was truncated, the response includes a NextToken. To get the next set of lifecycle configurations, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of lifecycle configurations to return in the response. Defaults to None.
        sort_by(str, optional): Sorts the list of results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. Defaults to None.
        name_contains(str, optional): A string in the lifecycle configuration name. This filter returns only lifecycle configurations whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only lifecycle configurations that were created before the specified time (timestamp). Defaults to None.
        creation_time_after(str, optional): A filter that returns only lifecycle configurations that were created after the specified time (timestamp). Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only lifecycle configurations that were modified before the specified time (timestamp). Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only lifecycle configurations that were modified after the specified time (timestamp). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.lifecycle_config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.lifecycle_config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_notebook_instance_lifecycle_configs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
        },
    )


async def update(
    hub,
    ctx,
    notebook_instance_lifecycle_config_name: str,
    on_create: List = None,
    on_start: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a notebook instance lifecycle configuration created with the CreateNotebookInstanceLifecycleConfig API.

    Args:
        notebook_instance_lifecycle_config_name(str): The name of the lifecycle configuration.
        on_create(List, optional): The shell script that runs only once, when you create a notebook instance. The shell script must be a base64-encoded string. Defaults to None.
        on_start(List, optional): The shell script that runs every time you start a notebook instance, including when you create the notebook instance. The shell script must be a base64-encoded string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.lifecycle_config.update(
                ctx, notebook_instance_lifecycle_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.lifecycle_config.update notebook_instance_lifecycle_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_notebook_instance_lifecycle_config",
        op_kwargs={
            "NotebookInstanceLifecycleConfigName": notebook_instance_lifecycle_config_name,
            "OnCreate": on_create,
            "OnStart": on_start,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def revoke(hub, ctx, job_id: str, reason: str, job_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    Changes the state of a signing job to REVOKED. This indicates that the signature is no longer valid.

    Args:
        job_id(str): ID of the signing job to be revoked.
        job_owner(str, optional): AWS account ID of the job owner. Defaults to None.
        reason(str): The reason for revoking the signing job.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signature.revoke(ctx, job_id=value, reason=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signature.revoke job_id=value, reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="revoke_signature",
        op_kwargs={"jobId": job_id, "jobOwner": job_owner, "reason": reason},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, compatible_runtime: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists Lambda layers and shows information about the latest version of each. Specify a runtime identifier to list only layers that indicate that they're compatible with that runtime.

    Args:
        compatible_runtime(str, optional): A runtime identifier. For example, go1.x. Defaults to None.
        marker(str, optional): A pagination token returned by a previous call. Defaults to None.
        max_items(int, optional): The maximum number of layers to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_layers",
        op_kwargs={
            "CompatibleRuntime": compatible_runtime,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, channel_ids: List = None, multiplex_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops running resources

    Args:
        channel_ids(List, optional): List of channel IDs. Defaults to None.
        multiplex_ids(List, optional): List of multiplex IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.stop.batch(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.stop.batch
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="batch_stop",
        op_kwargs={"ChannelIds": channel_ids, "MultiplexIds": multiplex_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, disk_name: str, instance_name: str, disk_path: str) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a block storage disk to a running or stopped Lightsail instance and exposes it to the instance with the specified disk name. The attach disk operation supports tag-based access control via resource tags applied to the resource identified by disk name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        disk_name(str): The unique Lightsail disk name (e.g., my-disk).
        instance_name(str): The name of the Lightsail instance where you want to utilize the storage disk.
        disk_path(str): The disk path to expose to the instance (e.g., /dev/xvdf).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.init.attach(
                ctx, disk_name=value, instance_name=value, disk_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.init.attach disk_name=value, instance_name=value, disk_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="attach_disk",
        op_kwargs={
            "diskName": disk_name,
            "instanceName": instance_name,
            "diskPath": disk_path,
        },
    )


async def create(
    hub,
    ctx,
    disk_name: str,
    availability_zone: str,
    size_in_gb: int,
    tags: List = None,
    add_ons: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a block storage disk that can be attached to an Amazon Lightsail instance in the same Availability Zone (e.g., us-east-2a). The create disk operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        disk_name(str): The unique Lightsail disk name (e.g., my-disk).
        availability_zone(str): The Availability Zone where you want to create the disk (e.g., us-east-2a). Use the same Availability Zone as the Lightsail instance to which you want to attach the disk. Use the get regions operation to list the Availability Zones where Lightsail is currently available.
        size_in_gb(int): The size of the disk in GB (e.g., 32).
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.
        add_ons(List, optional): An array of objects that represent the add-ons to enable for the new disk. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.init.create(
                ctx, disk_name=value, availability_zone=value, size_in_gb=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.init.create disk_name=value, availability_zone=value, size_in_gb=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_disk",
        op_kwargs={
            "diskName": disk_name,
            "availabilityZone": availability_zone,
            "sizeInGb": size_in_gb,
            "tags": tags,
            "addOns": add_ons,
        },
    )


async def delete(hub, ctx, disk_name: str, force_delete_add_ons: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified block storage disk. The disk must be in the available state (not attached to a Lightsail instance).  The disk may remain in the deleting state for several minutes.  The delete disk operation supports tag-based access control via resource tags applied to the resource identified by disk name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        disk_name(str): The unique name of the disk you want to delete (e.g., my-disk).
        force_delete_add_ons(bool, optional): A Boolean value to indicate whether to delete the enabled add-ons for the disk. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.init.delete(ctx, disk_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.init.delete disk_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_disk",
        op_kwargs={"diskName": disk_name, "forceDeleteAddOns": force_delete_add_ons},
    )


async def detach(hub, ctx, disk_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Detaches a stopped block storage disk from a Lightsail instance. Make sure to unmount any file systems on the device within your operating system before stopping the instance and detaching the disk. The detach disk operation supports tag-based access control via resource tags applied to the resource identified by disk name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        disk_name(str): The unique name of the disk you want to detach from your instance (e.g., my-disk).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.init.detach(ctx, disk_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.init.detach disk_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="detach_disk",
        op_kwargs={"diskName": disk_name},
    )


async def get(hub, ctx, disk_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific block storage disk.

    Args:
        disk_name(str): The name of the disk (e.g., my-disk).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.init.get(ctx, disk_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.init.get disk_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_disk",
        op_kwargs={"diskName": disk_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all block storage disks in your AWS account and region.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetDisks request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_disks",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    savings_plans_type: str,
    term_in_years: str,
    payment_option: str,
    lookback_period_in_days: str,
    account_scope: str = None,
    next_page_token: str = None,
    page_size: int = None,
    filter_: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves your request parameters, Savings Plan Recommendations Summary and Details.

    Args:
        savings_plans_type(str): The Savings Plans recommendation type requested.
        term_in_years(str): The savings plan recommendation term used to generate these recommendations.
        payment_option(str): The payment option used to generate these recommendations.
        account_scope(str, optional): The account scope that you want your recommendations for. Amazon Web Services calculates recommendations including the management account and member accounts if the value is set to PAYER. If the value is LINKED, recommendations are calculated for individual member accounts only. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.
        page_size(int, optional): The number of recommendations that you want returned in a single response object. Defaults to None.
        lookback_period_in_days(str): The lookback period used to generate the recommendation.
        filter_(Dict, optional): You can filter your recommendations by Account ID with the LINKED_ACCOUNT dimension. To filter your recommendations by Account ID, specify Key as LINKED_ACCOUNT and Value as the comma-separated Acount ID(s) for which you want to see Savings Plans purchase recommendations. For GetSavingsPlansPurchaseRecommendation, the Filter does not include CostCategories or Tags. It only includes Dimensions. With Dimensions, Key must be LINKED_ACCOUNT and Value can be a single Account ID or multiple comma-separated Account IDs for which you want to see Savings Plans Purchase Recommendations. AND and OR operators are not supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.saving_plan.purchase_recommendation.get(
                ctx,
                savings_plans_type=value,
                term_in_years=value,
                payment_option=value,
                lookback_period_in_days=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.saving_plan.purchase_recommendation.get savings_plans_type=value, term_in_years=value, payment_option=value, lookback_period_in_days=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_savings_plans_purchase_recommendation",
        op_kwargs={
            "SavingsPlansType": savings_plans_type,
            "TermInYears": term_in_years,
            "PaymentOption": payment_option,
            "AccountScope": account_scope,
            "NextPageToken": next_page_token,
            "PageSize": page_size,
            "LookbackPeriodInDays": lookback_period_in_days,
            "Filter": filter_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    notebook_instance_name: str,
    instance_type: str,
    role_arn: str,
    subnet_id: str = None,
    security_group_ids: List = None,
    kms_key_id: str = None,
    tags: List = None,
    lifecycle_config_name: str = None,
    direct_internet_access: str = None,
    volume_size_in_gb: int = None,
    accelerator_types: List = None,
    default_code_repository: str = None,
    additional_code_repositories: List = None,
    root_access: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon SageMaker notebook instance. A notebook instance is a machine learning (ML) compute instance running on a Jupyter notebook.  In a CreateNotebookInstance request, specify the type of ML compute instance that you want to run. Amazon SageMaker launches the instance, installs common libraries that you can use to explore datasets for model training, and attaches an ML storage volume to the notebook instance.  Amazon SageMaker also provides a set of example notebooks. Each notebook demonstrates how to use Amazon SageMaker with a specific algorithm or with a machine learning framework.  After receiving the request, Amazon SageMaker does the following:   Creates a network interface in the Amazon SageMaker VPC.   (Option) If you specified SubnetId, Amazon SageMaker creates a network interface in your own VPC, which is inferred from the subnet ID that you provide in the input. When creating this network interface, Amazon SageMaker attaches the security group that you specified in the request to the network interface that it creates in your VPC.   Launches an EC2 instance of the type specified in the request in the Amazon SageMaker VPC. If you specified SubnetId of your VPC, Amazon SageMaker specifies both network interfaces when launching this instance. This enables inbound traffic from your own VPC to the notebook instance, assuming that the security groups allow it.   After creating the notebook instance, Amazon SageMaker returns its Amazon Resource Name (ARN). You can't change the name of a notebook instance after you create it. After Amazon SageMaker creates the notebook instance, you can connect to the Jupyter server and work in Jupyter notebooks. For example, you can write code to explore a dataset that you can use for model training, train a model, host models by creating Amazon SageMaker endpoints, and validate hosted models.  For more information, see How It Works.

    Args:
        notebook_instance_name(str): The name of the new notebook instance.
        instance_type(str): The type of ML compute instance to launch for the notebook instance.
        subnet_id(str, optional): The ID of the subnet in a VPC to which you would like to have a connectivity from your ML compute instance. . Defaults to None.
        security_group_ids(List, optional): The VPC security group IDs, in the form sg-xxxxxxxx. The security groups must be for the same VPC as specified in the subnet. . Defaults to None.
        role_arn(str):  When you send any requests to Amazon Web Services resources from the notebook instance, Amazon SageMaker assumes this role to perform tasks on your behalf. You must grant this role necessary permissions so Amazon SageMaker can perform these tasks. The policy must allow the Amazon SageMaker service principal (sagemaker.amazonaws.com) permissions to assume this role. For more information, see Amazon SageMaker Roles.   To be able to pass this role to Amazon SageMaker, the caller of this API must have the iam:PassRole permission. .
        kms_key_id(str, optional): The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service key that Amazon SageMaker uses to encrypt data on the storage volume attached to your notebook instance. The KMS key you provide must be enabled. For information, see Enabling and Disabling Keys in the Amazon Web Services Key Management Service Developer Guide. Defaults to None.
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.
        lifecycle_config_name(str, optional): The name of a lifecycle configuration to associate with the notebook instance. For information about lifestyle configurations, see Step 2.1: (Optional) Customize a Notebook Instance. Defaults to None.
        direct_internet_access(str, optional): Sets whether Amazon SageMaker provides internet access to the notebook instance. If you set this to Disabled this notebook instance is able to access resources only in your VPC, and is not be able to connect to Amazon SageMaker training and endpoint services unless you configure a NAT Gateway in your VPC. For more information, see Notebook Instances Are Internet-Enabled by Default. You can set the value of this parameter to Disabled only if you set a value for the SubnetId parameter. Defaults to None.
        volume_size_in_gb(int, optional): The size, in GB, of the ML storage volume to attach to the notebook instance. The default value is 5 GB. Defaults to None.
        accelerator_types(List, optional): A list of Elastic Inference (EI) instance types to associate with this notebook instance. Currently, only one instance type can be associated with a notebook instance. For more information, see Using Elastic Inference in Amazon SageMaker. Defaults to None.
        default_code_repository(str, optional): A Git repository to associate with the notebook instance as its default code repository. This can be either the name of a Git repository stored as a resource in your account, or the URL of a Git repository in Amazon Web Services CodeCommit or in any other Git repository. When you open a notebook instance, it opens in the directory that contains this repository. For more information, see Associating Git Repositories with Amazon SageMaker Notebook Instances. Defaults to None.
        additional_code_repositories(List, optional): An array of up to three Git repositories to associate with the notebook instance. These can be either the names of Git repositories stored as resources in your account, or the URL of Git repositories in Amazon Web Services CodeCommit or in any other Git repository. These repositories are cloned at the same level as the default repository of your notebook instance. For more information, see Associating Git Repositories with Amazon SageMaker Notebook Instances. Defaults to None.
        root_access(str, optional): Whether root access is enabled or disabled for users of the notebook instance. The default value is Enabled.  Lifecycle configurations need root access to be able to set up a notebook instance. Because of this, lifecycle configurations associated with a notebook instance always run with root access even if you disable root access for users. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.create(
                ctx, notebook_instance_name=value, instance_type=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.create notebook_instance_name=value, instance_type=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_notebook_instance",
        op_kwargs={
            "NotebookInstanceName": notebook_instance_name,
            "InstanceType": instance_type,
            "SubnetId": subnet_id,
            "SecurityGroupIds": security_group_ids,
            "RoleArn": role_arn,
            "KmsKeyId": kms_key_id,
            "Tags": tags,
            "LifecycleConfigName": lifecycle_config_name,
            "DirectInternetAccess": direct_internet_access,
            "VolumeSizeInGB": volume_size_in_gb,
            "AcceleratorTypes": accelerator_types,
            "DefaultCodeRepository": default_code_repository,
            "AdditionalCodeRepositories": additional_code_repositories,
            "RootAccess": root_access,
        },
    )


async def delete(hub, ctx, notebook_instance_name: str) -> None:
    r"""
    **Autogenerated function**

     Deletes an Amazon SageMaker notebook instance. Before you can delete a notebook instance, you must call the StopNotebookInstance API.   When you delete a notebook instance, you lose all of your data. Amazon SageMaker removes the ML compute instance, and deletes the ML storage volume and the network interface associated with the notebook instance.

    Args:
        notebook_instance_name(str): The name of the Amazon SageMaker notebook instance to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.delete(
                ctx, notebook_instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.delete notebook_instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_notebook_instance",
        op_kwargs={"NotebookInstanceName": notebook_instance_name},
    )


async def describe(hub, ctx, notebook_instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a notebook instance.

    Args:
        notebook_instance_name(str): The name of the notebook instance that you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.describe(
                ctx, notebook_instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.describe notebook_instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_notebook_instance",
        op_kwargs={"NotebookInstanceName": notebook_instance_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    sort_by: str = None,
    sort_order: str = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
    last_modified_time_before: str = None,
    last_modified_time_after: str = None,
    status_equals: str = None,
    notebook_instance_lifecycle_config_name_contains: str = None,
    default_code_repository_contains: str = None,
    additional_code_repository_equals: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the Amazon SageMaker notebook instances in the requester's account in an Amazon Web Services Region.

    Args:
        next_token(str, optional):  If the previous call to the ListNotebookInstances is truncated, the response includes a NextToken. You can use this token in your subsequent ListNotebookInstances request to fetch the next set of notebook instances.   You might specify a filter or a sort order in your request. When response is truncated, you must use the same values for the filer and sort order in the next request.  . Defaults to None.
        max_results(int, optional): The maximum number of notebook instances to return. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is Name. Defaults to None.
        sort_order(str, optional): The sort order for results. . Defaults to None.
        name_contains(str, optional): A string in the notebook instances' name. This filter returns only notebook instances whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only notebook instances that were created before the specified time (timestamp). . Defaults to None.
        creation_time_after(str, optional): A filter that returns only notebook instances that were created after the specified time (timestamp). Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only notebook instances that were modified before the specified time (timestamp). Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only notebook instances that were modified after the specified time (timestamp). Defaults to None.
        status_equals(str, optional): A filter that returns only notebook instances with the specified status. Defaults to None.
        notebook_instance_lifecycle_config_name_contains(str, optional): A string in the name of a notebook instances lifecycle configuration associated with this notebook instance. This filter returns only notebook instances associated with a lifecycle configuration with a name that contains the specified string. Defaults to None.
        default_code_repository_contains(str, optional): A string in the name or URL of a Git repository associated with this notebook instance. This filter returns only notebook instances associated with a git repository with a name that contains the specified string. Defaults to None.
        additional_code_repository_equals(str, optional): A filter that returns only notebook instances with associated with the specified git repository. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_notebook_instances",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "StatusEquals": status_equals,
            "NotebookInstanceLifecycleConfigNameContains": notebook_instance_lifecycle_config_name_contains,
            "DefaultCodeRepositoryContains": default_code_repository_contains,
            "AdditionalCodeRepositoryEquals": additional_code_repository_equals,
        },
    )


async def start(hub, ctx, notebook_instance_name: str) -> None:
    r"""
    **Autogenerated function**

    Launches an ML compute instance with the latest version of the libraries and attaches your ML storage volume. After configuring the notebook instance, Amazon SageMaker sets the notebook instance status to InService. A notebook instance's status must be InService before you can connect to your Jupyter notebook.

    Args:
        notebook_instance_name(str): The name of the notebook instance to start.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.start(
                ctx, notebook_instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.start notebook_instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="start_notebook_instance",
        op_kwargs={"NotebookInstanceName": notebook_instance_name},
    )


async def stop(hub, ctx, notebook_instance_name: str) -> None:
    r"""
    **Autogenerated function**

    Terminates the ML compute instance. Before terminating the instance, Amazon SageMaker disconnects the ML storage volume from it. Amazon SageMaker preserves the ML storage volume. Amazon SageMaker stops charging you for the ML compute instance when you call StopNotebookInstance. To access data on the ML storage volume for a notebook instance that has been terminated, call the StartNotebookInstance API. StartNotebookInstance launches another ML compute instance, configures it, and attaches the preserved ML storage volume so you can continue your work.

    Args:
        notebook_instance_name(str): The name of the notebook instance to terminate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.stop(
                ctx, notebook_instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.stop notebook_instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_notebook_instance",
        op_kwargs={"NotebookInstanceName": notebook_instance_name},
    )


async def update(
    hub,
    ctx,
    notebook_instance_name: str,
    instance_type: str = None,
    role_arn: str = None,
    lifecycle_config_name: str = None,
    disassociate_lifecycle_config: bool = None,
    volume_size_in_gb: int = None,
    default_code_repository: str = None,
    additional_code_repositories: List = None,
    accelerator_types: List = None,
    disassociate_accelerator_types: bool = None,
    disassociate_default_code_repository: bool = None,
    disassociate_additional_code_repositories: bool = None,
    root_access: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a notebook instance. NotebookInstance updates include upgrading or downgrading the ML compute instance used for your notebook instance to accommodate changes in your workload requirements.

    Args:
        notebook_instance_name(str): The name of the notebook instance to update.
        instance_type(str, optional): The Amazon ML compute instance type. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker can assume to access the notebook instance. For more information, see Amazon SageMaker Roles.   To be able to pass this role to Amazon SageMaker, the caller of this API must have the iam:PassRole permission. . Defaults to None.
        lifecycle_config_name(str, optional): The name of a lifecycle configuration to associate with the notebook instance. For information about lifestyle configurations, see Step 2.1: (Optional) Customize a Notebook Instance. Defaults to None.
        disassociate_lifecycle_config(bool, optional): Set to true to remove the notebook instance lifecycle configuration currently associated with the notebook instance. This operation is idempotent. If you specify a lifecycle configuration that is not associated with the notebook instance when you call this method, it does not throw an error. Defaults to None.
        volume_size_in_gb(int, optional): The size, in GB, of the ML storage volume to attach to the notebook instance. The default value is 5 GB. ML storage volumes are encrypted, so Amazon SageMaker can't determine the amount of available free space on the volume. Because of this, you can increase the volume size when you update a notebook instance, but you can't decrease the volume size. If you want to decrease the size of the ML storage volume in use, create a new notebook instance with the desired size. Defaults to None.
        default_code_repository(str, optional): The Git repository to associate with the notebook instance as its default code repository. This can be either the name of a Git repository stored as a resource in your account, or the URL of a Git repository in Amazon Web Services CodeCommit or in any other Git repository. When you open a notebook instance, it opens in the directory that contains this repository. For more information, see Associating Git Repositories with Amazon SageMaker Notebook Instances. Defaults to None.
        additional_code_repositories(List, optional): An array of up to three Git repositories to associate with the notebook instance. These can be either the names of Git repositories stored as resources in your account, or the URL of Git repositories in Amazon Web Services CodeCommit or in any other Git repository. These repositories are cloned at the same level as the default repository of your notebook instance. For more information, see Associating Git Repositories with Amazon SageMaker Notebook Instances. Defaults to None.
        accelerator_types(List, optional): A list of the Elastic Inference (EI) instance types to associate with this notebook instance. Currently only one EI instance type can be associated with a notebook instance. For more information, see Using Elastic Inference in Amazon SageMaker. Defaults to None.
        disassociate_accelerator_types(bool, optional): A list of the Elastic Inference (EI) instance types to remove from this notebook instance. This operation is idempotent. If you specify an accelerator type that is not associated with the notebook instance when you call this method, it does not throw an error. Defaults to None.
        disassociate_default_code_repository(bool, optional): The name or URL of the default Git repository to remove from this notebook instance. This operation is idempotent. If you specify a Git repository that is not associated with the notebook instance when you call this method, it does not throw an error. Defaults to None.
        disassociate_additional_code_repositories(bool, optional): A list of names or URLs of the default Git repositories to remove from this notebook instance. This operation is idempotent. If you specify a Git repository that is not associated with the notebook instance when you call this method, it does not throw an error. Defaults to None.
        root_access(str, optional): Whether root access is enabled or disabled for users of the notebook instance. The default value is Enabled.  If you set this to Disabled, users don't have root access on the notebook instance, but lifecycle configuration scripts still run with root permissions. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.notebook_instance.init.update(
                ctx, notebook_instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.notebook_instance.init.update notebook_instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_notebook_instance",
        op_kwargs={
            "NotebookInstanceName": notebook_instance_name,
            "InstanceType": instance_type,
            "RoleArn": role_arn,
            "LifecycleConfigName": lifecycle_config_name,
            "DisassociateLifecycleConfig": disassociate_lifecycle_config,
            "VolumeSizeInGB": volume_size_in_gb,
            "DefaultCodeRepository": default_code_repository,
            "AdditionalCodeRepositories": additional_code_repositories,
            "AcceleratorTypes": accelerator_types,
            "DisassociateAcceleratorTypes": disassociate_accelerator_types,
            "DisassociateDefaultCodeRepository": disassociate_default_code_repository,
            "DisassociateAdditionalCodeRepositories": disassociate_additional_code_repositories,
            "RootAccess": root_access,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stack_id: str,
    name: str,
    type_: str,
    shortname: str = None,
    description: str = None,
    data_sources: List = None,
    app_source: Dict = None,
    domains: List = None,
    enable_ssl: bool = None,
    ssl_configuration: Dict = None,
    attributes: Dict = None,
    environment: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an app for a specified stack. For more information, see Creating Apps.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
        shortname(str, optional): The app's short name. Defaults to None.
        name(str): The app name.
        description(str, optional): A description of the app. Defaults to None.
        data_sources(List, optional): The app's data source. Defaults to None.
        type_(str): The app type. Each supported type is associated with a particular layer. For example, PHP applications are associated with a PHP layer. AWS OpsWorks Stacks deploys an application to those instances that are members of the corresponding layer. If your app isn't one of the standard types, or you prefer to implement your own Deploy recipes, specify other.
        app_source(Dict, optional): A Source object that specifies the app repository. Defaults to None.
        domains(List, optional): The app virtual host settings, with multiple domains separated by commas. For example: 'www.example.com, example.com' . Defaults to None.
        enable_ssl(bool, optional): Whether to enable SSL for the app. Defaults to None.
        ssl_configuration(Dict, optional): An SslConfiguration object with the SSL configuration. Defaults to None.
        attributes(Dict, optional): One or more user-defined key/value pairs to be added to the stack attributes. Defaults to None.
        environment(List, optional): An array of EnvironmentVariable objects that specify environment variables to be associated with the app. After you deploy the app, these variables are defined on the associated app server instance. For more information, see  Environment Variables. There is no specific limit on the number of environment variables. However, the size of the associated data structure - which includes the variables' names, values, and protected flag values - cannot exceed 20 KB. This limit should accommodate most if not all use cases. Exceeding it will cause an exception with the message, "Environment: is too large (maximum is 20KB)."  If you have specified one or more environment variables, you cannot modify the stack's Chef version. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.app.create(ctx, stack_id=value, name=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.app.create stack_id=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="create_app",
        op_kwargs={
            "StackId": stack_id,
            "Shortname": shortname,
            "Name": name,
            "Description": description,
            "DataSources": data_sources,
            "Type": type_,
            "AppSource": app_source,
            "Domains": domains,
            "EnableSsl": enable_ssl,
            "SslConfiguration": ssl_configuration,
            "Attributes": attributes,
            "Environment": environment,
        },
    )


async def delete(hub, ctx, app_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified app.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        app_id(str): The app ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.app.delete(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.app.delete app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="delete_app",
        op_kwargs={"AppId": app_id},
    )


async def update(
    hub,
    ctx,
    app_id: str,
    name: str = None,
    description: str = None,
    data_sources: List = None,
    type_: str = None,
    app_source: Dict = None,
    domains: List = None,
    enable_ssl: bool = None,
    ssl_configuration: Dict = None,
    attributes: Dict = None,
    environment: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a specified app.  Required Permissions: To use this action, an IAM user must have a Deploy or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        app_id(str): The app ID.
        name(str, optional): The app name. Defaults to None.
        description(str, optional): A description of the app. Defaults to None.
        data_sources(List, optional): The app's data sources. Defaults to None.
        type_(str, optional): The app type. Defaults to None.
        app_source(Dict, optional): A Source object that specifies the app repository. Defaults to None.
        domains(List, optional): The app's virtual host settings, with multiple domains separated by commas. For example: 'www.example.com, example.com' . Defaults to None.
        enable_ssl(bool, optional): Whether SSL is enabled for the app. Defaults to None.
        ssl_configuration(Dict, optional): An SslConfiguration object with the SSL configuration. Defaults to None.
        attributes(Dict, optional): One or more user-defined key/value pairs to be added to the stack attributes. Defaults to None.
        environment(List, optional): An array of EnvironmentVariable objects that specify environment variables to be associated with the app. After you deploy the app, these variables are defined on the associated app server instances.For more information, see  Environment Variables. There is no specific limit on the number of environment variables. However, the size of the associated data structure - which includes the variables' names, values, and protected flag values - cannot exceed 20 KB. This limit should accommodate most if not all use cases. Exceeding it will cause an exception with the message, "Environment: is too large (maximum is 20 KB)."  If you have specified one or more environment variables, you cannot modify the stack's Chef version. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.app.update(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.app.update app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_app",
        op_kwargs={
            "AppId": app_id,
            "Name": name,
            "Description": description,
            "DataSources": data_sources,
            "Type": type_,
            "AppSource": app_source,
            "Domains": domains,
            "EnableSsl": enable_ssl,
            "SslConfiguration": ssl_configuration,
            "Attributes": attributes,
            "Environment": environment,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    configuration_set_name: str,
    tracking_options: Dict = None,
    delivery_options: Dict = None,
    reputation_options: Dict = None,
    sending_options: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a configuration set. Configuration sets are groups of rules that you can apply to the emails you send using Amazon Pinpoint. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.

    Args:
        configuration_set_name(str): The name of the configuration set.
        tracking_options(Dict, optional): An object that defines the open and click tracking options for emails that you send using the configuration set. Defaults to None.
        delivery_options(Dict, optional): An object that defines the dedicated IP pool that is used to send emails that you send using the configuration set. Defaults to None.
        reputation_options(Dict, optional): An object that defines whether or not Amazon Pinpoint collects reputation metrics for the emails that you send that use the configuration set. Defaults to None.
        sending_options(Dict, optional): An object that defines whether or not Amazon Pinpoint can send email that you send using the configuration set. Defaults to None.
        tags(List, optional): An array of objects that define the tags (keys and values) that you want to associate with the configuration set. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.init.create(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.init.create configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="create_configuration_set",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "TrackingOptions": tracking_options,
            "DeliveryOptions": delivery_options,
            "ReputationOptions": reputation_options,
            "SendingOptions": sending_options,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an existing configuration set. In Amazon Pinpoint, configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.init.delete(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.init.delete configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="delete_configuration_set",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def get(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Get information about an existing configuration set, including the dedicated IP pool that it's associated with, whether or not it's enabled for sending email, and more. In Amazon Pinpoint, configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to obtain more information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.init.get(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.init.get configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="get_configuration_set",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    List all of the configuration sets associated with your Amazon Pinpoint account in the current region. In Amazon Pinpoint, configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.

    Args:
        next_token(str, optional): A token returned from a previous call to ListConfigurationSets to indicate the position in the list of configuration sets. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListConfigurationSets. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="list_configuration_sets",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(hub, ctx, target_arn: str, initiator_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target and initiator pair. This operation is supported in volume and tape gateway types.

    Args:
        target_arn(str): The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return to retrieve the TargetARN for specified VolumeARN.
        initiator_name(str): The iSCSI initiator that connects to the target.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.chap_credential.delete_multiple(
                ctx, target_arn=value, initiator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.chap_credential.delete_multiple target_arn=value, initiator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_chap_credentials",
        op_kwargs={"TargetARN": target_arn, "InitiatorName": initiator_name},
    )


async def describe_all(hub, ctx, target_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of Challenge-Handshake Authentication Protocol (CHAP) credentials information for a specified iSCSI target, one for each target-initiator pair. This operation is supported in the volume and tape gateway types.

    Args:
        target_arn(str): The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return to retrieve the TargetARN for specified VolumeARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.chap_credential.describe_all(
                ctx, target_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.chap_credential.describe_all target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_chap_credentials",
        op_kwargs={"TargetARN": target_arn},
    )


async def update_multiple(
    hub,
    ctx,
    target_arn: str,
    secret_to_authenticate_initiator: str,
    initiator_name: str,
    secret_to_authenticate_target: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target. By default, a gateway does not have CHAP enabled; however, for added security, you might use it. This operation is supported in the volume and tape gateway types.  When you update CHAP credentials, all existing connections on the target are closed and initiators must reconnect with the new credentials.

    Args:
        target_arn(str): The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return the TargetARN for specified VolumeARN.
        secret_to_authenticate_initiator(str): The secret key that the initiator (for example, the Windows client) must provide to participate in mutual CHAP with the target.  The secret key must be between 12 and 16 bytes when encoded in UTF-8. .
        initiator_name(str): The iSCSI initiator that connects to the target.
        secret_to_authenticate_target(str, optional): The secret key that the target must provide to participate in mutual CHAP with the initiator (e.g. Windows client). Byte constraints: Minimum bytes of 12. Maximum bytes of 16.  The secret key must be between 12 and 16 bytes when encoded in UTF-8. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.chap_credential.update_multiple(
                ctx, target_arn=value, secret_to_authenticate_initiator=value, initiator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.chap_credential.update_multiple target_arn=value, secret_to_authenticate_initiator=value, initiator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_chap_credentials",
        op_kwargs={
            "TargetARN": target_arn,
            "SecretToAuthenticateInitiator": secret_to_authenticate_initiator,
            "InitiatorName": initiator_name,
            "SecretToAuthenticateTarget": secret_to_authenticate_target,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    device_id: str,
    from_time_stamp: str,
    to_time_stamp: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
       **Autogenerated function**

       Using a device ID, returns a DeviceEventsResponse object containing an
        array of events for the device.

       Args:
           device_id(str): The unique identifier of the device.
           from_time_stamp(str): The start date for the device event query, in ISO8061 format. For example,
    2018-03-28T15:45:12.880Z
    .
           max_results(int, optional): The maximum number of results to return per request. If not set, a default value of
    100 is used. Defaults to None.
           next_token(str, optional): The token to retrieve the next set of results. Defaults to None.
           to_time_stamp(str): The end date for the device event query, in ISO8061 format. For example,
    2018-03-28T15:45:12.880Z
    .

       Returns:
           Dict

       Examples:
           Call from code:

           .. code-block:: python

               await hub.exec.aws_auto.iot1click_device.device.event.list_all(
                   ctx, device_id=value, from_time_stamp=value, to_time_stamp=value
               )

           Call from CLI:

           .. code-block:: bash

               $ idem exec aws_auto.iot1click_device.device.event.list_all device_id=value, from_time_stamp=value, to_time_stamp=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="list_device_events",
        op_kwargs={
            "DeviceId": device_id,
            "FromTimeStamp": from_time_stamp,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ToTimeStamp": to_time_stamp,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_name: str,
    certificate_name: str = None,
    certificate_body: str = None,
    certificate_private_key: str = None,
    certificate_chain: str = None,
    certificate_arn: str = None,
    regional_certificate_name: str = None,
    regional_certificate_arn: str = None,
    endpoint_configuration: Dict = None,
    tags: Dict = None,
    security_policy: str = None,
    mutual_tls_authentication: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new domain name.

    Args:
        domain_name(str): [Required] The name of the DomainName resource.
        certificate_name(str, optional): The user-friendly name of the certificate that will be used by edge-optimized endpoint for this domain name. Defaults to None.
        certificate_body(str, optional): [Deprecated] The body of the server certificate that will be used by edge-optimized endpoint for this domain name provided by your certificate authority. Defaults to None.
        certificate_private_key(str, optional): [Deprecated] Your edge-optimized endpoint's domain name certificate's private key. Defaults to None.
        certificate_chain(str, optional): [Deprecated] The intermediate certificates and optionally the root certificate, one after the other without any blank lines, used by an edge-optimized endpoint for this domain name. If you include the root certificate, your certificate chain must start with intermediate certificates and end with the root certificate. Use the intermediate certificates that were provided by your certificate authority. Do not include any intermediaries that are not in the chain of trust path. Defaults to None.
        certificate_arn(str, optional): The reference to an AWS-managed certificate that will be used by edge-optimized endpoint for this domain name. AWS Certificate Manager is the only supported source. Defaults to None.
        regional_certificate_name(str, optional): The user-friendly name of the certificate that will be used by regional endpoint for this domain name. Defaults to None.
        regional_certificate_arn(str, optional): The reference to an AWS-managed certificate that will be used by regional endpoint for this domain name. AWS Certificate Manager is the only supported source. Defaults to None.
        endpoint_configuration(Dict, optional): The endpoint configuration of this DomainName showing the endpoint types of the domain name. Defaults to None.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.
        security_policy(str, optional): The Transport Layer Security (TLS) version + cipher suite for this DomainName. The valid values are TLS_1_0 and TLS_1_2. Defaults to None.
        mutual_tls_authentication(Dict, optional): If specified, API Gateway performs two-way authentication between the client and the server. Clients must present a trusted certificate to access your custom domain name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.domain_name.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.domain_name.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_domain_name",
        op_kwargs={
            "domainName": domain_name,
            "certificateName": certificate_name,
            "certificateBody": certificate_body,
            "certificatePrivateKey": certificate_private_key,
            "certificateChain": certificate_chain,
            "certificateArn": certificate_arn,
            "regionalCertificateName": regional_certificate_name,
            "regionalCertificateArn": regional_certificate_arn,
            "endpointConfiguration": endpoint_configuration,
            "tags": tags,
            "securityPolicy": security_policy,
            "mutualTlsAuthentication": mutual_tls_authentication,
        },
    )


async def delete(hub, ctx, domain_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the DomainName resource.

    Args:
        domain_name(str): [Required] The name of the DomainName resource to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.domain_name.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.domain_name.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_domain_name",
        op_kwargs={"domainName": domain_name},
    )


async def get(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Represents a domain name that is contained in a simpler, more intuitive URL that can be called.

    Args:
        domain_name(str): [Required] The name of the DomainName resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.domain_name.get(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.domain_name.get domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_domain_name",
        op_kwargs={"domainName": domain_name},
    )


async def get_all(hub, ctx, position: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Represents a collection of DomainName resources.

    Args:
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.domain_name.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.domain_name.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_domain_names",
        op_kwargs={"position": position, "limit": limit},
    )


async def update(hub, ctx, domain_name: str, patch_operations: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about the DomainName resource.

    Args:
        domain_name(str): [Required] The name of the DomainName resource to be changed.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.domain_name.update(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.domain_name.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_domain_name",
        op_kwargs={"domainName": domain_name, "patchOperations": patch_operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, organization_id: str, name: str, type_: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon WorkMail resource.

    Args:
        organization_id(str): The identifier associated with the organization for which the resource is created.
        name(str): The name of the new resource.
        type_(str): The type of the new resource. The available types are equipment and room.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.create(
                ctx, organization_id=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.create organization_id=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="create_resource",
        op_kwargs={"OrganizationId": organization_id, "Name": name, "Type": type_},
    )


async def delete(hub, ctx, organization_id: str, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified resource.

    Args:
        organization_id(str): The identifier associated with the organization from which the resource is deleted.
        resource_id(str): The identifier of the resource to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.delete(
                ctx, organization_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.delete organization_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_resource",
        op_kwargs={"OrganizationId": organization_id, "ResourceId": resource_id},
    )


async def describe(hub, ctx, organization_id: str, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data available for the resource.

    Args:
        organization_id(str): The identifier associated with the organization for which the resource is described.
        resource_id(str): The identifier of the resource to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.describe(
                ctx, organization_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.describe organization_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="describe_resource",
        op_kwargs={"OrganizationId": organization_id, "ResourceId": resource_id},
    )


async def list_all(
    hub, ctx, organization_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summaries of the organization's resources.

    Args:
        organization_id(str): The identifier for the organization under which the resources exist.
        next_token(str, optional): The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.list_all(ctx, organization_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.list_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_resources",
        op_kwargs={
            "OrganizationId": organization_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Applies the specified tags to the specified Amazon WorkMail organization resource.

    Args:
        resource_arn(str): The resource ARN.
        tags(List): The tag key-value pairs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Untags the specified tags from the specified Amazon WorkMail organization resource.

    Args:
        resource_arn(str): The resource ARN.
        tag_keys(List): The tag keys.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )


async def update(
    hub,
    ctx,
    organization_id: str,
    resource_id: str,
    name: str = None,
    booking_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates data for the resource. To have the latest information, it must be preceded by a DescribeResource call. The dataset in the request should be the one expected when performing another DescribeResource call.

    Args:
        organization_id(str): The identifier associated with the organization for which the resource is updated.
        resource_id(str): The identifier of the resource to be updated.
        name(str, optional): The name of the resource to be updated. Defaults to None.
        booking_options(Dict, optional): The resource's booking options to be updated. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.resource.init.update(
                ctx, organization_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.resource.init.update organization_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="update_resource",
        op_kwargs={
            "OrganizationId": organization_id,
            "ResourceId": resource_id,
            "Name": name,
            "BookingOptions": booking_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified pronunciation lexicon stored in an AWS Region. A lexicon which has been deleted is not available for speech synthesis, nor is it possible to retrieve it using either the GetLexicon or ListLexicon APIs. For more information, see Managing Lexicons.

    Args:
        name(str): The name of the lexicon to delete. Must be an existing lexicon in the region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.lexicon.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.lexicon.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="polly", operation="delete_lexicon", op_kwargs={"Name": name}
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the content of the specified pronunciation lexicon stored in an AWS Region. For more information, see Managing Lexicons.

    Args:
        name(str): Name of the lexicon.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.lexicon.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.lexicon.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="polly", operation="get_lexicon", op_kwargs={"Name": name}
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of pronunciation lexicons stored in an AWS Region. For more information, see Managing Lexicons.

    Args:
        next_token(str, optional): An opaque pagination token returned from previous ListLexicons operation. If present, indicates where to continue the list of lexicons. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.lexicon.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.lexicon.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="list_lexicons",
        op_kwargs={"NextToken": next_token},
    )


async def put(hub, ctx, name: str, content: str) -> Dict:
    r"""
    **Autogenerated function**

    Stores a pronunciation lexicon in an AWS Region. If a lexicon with the same name already exists in the region, it is overwritten by the new lexicon. Lexicon operations have eventual consistency, therefore, it might take some time before the lexicon is available to the SynthesizeSpeech operation. For more information, see Managing Lexicons.

    Args:
        name(str): Name of the lexicon. The name must follow the regular express format [0-9A-Za-z]{1,20}. That is, the name is a case-sensitive alphanumeric string up to 20 characters long. .
        content(str): Content of the PLS lexicon as string data.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.lexicon.put(ctx, name=value, content=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.lexicon.put name=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="put_lexicon",
        op_kwargs={"Name": name, "Content": content},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, map_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the map style descriptor from a map resource.  The style descriptor contains speciﬁcations on how features render on a map. For example, what data to display, what order to display the data in, and the style for the data. Style descriptors follow the Mapbox Style Specification.

    Args:
        map_name(str): The map resource to retrieve the style descriptor from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.map_.style_descriptor.get(ctx, map_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.map_.style_descriptor.get map_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="get_map_style_descriptor",
        op_kwargs={"MapName": map_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, job_id: str, client_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Requests the details of a job for a third party action. Used for partner actions only.  When this API is called, AWS CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts. This API also returns any secret values defined for the action.

    Args:
        job_id(str): The unique system-generated ID used for identifying the job.
        client_token(str): The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.third_party_job.detail.get_all(
                ctx, job_id=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.third_party_job.detail.get_all job_id=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="get_third_party_job_details",
        op_kwargs={"jobId": job_id, "clientToken": client_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "event_type"


async def list_all(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the event types available for configuring notifications.

    Args:
        filters(List, optional): The filters to use to return information by service or resource type. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-negative integer used to limit the number of returned results. The default number is 50. The maximum number of results that can be returned is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.event_type_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.event_type.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="list_event_types",
        op_kwargs={
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, account_id: str, vault_name: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns information about a job you previously initiated, including the job initiation date, the user who initiated the job, the job status code/message and the Amazon SNS topic to notify after Amazon S3 Glacier (Glacier) completes the job. For more information about initiating a job, see InitiateJob.   This operation enables you to check the status of your job. However, it is strongly recommended that you set up an Amazon SNS topic and specify it in your initiate job request so that Glacier can notify the topic after it completes the job.  A job ID will not expire for at least 24 hours after Glacier completes the job. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For more information about using this operation, see the documentation for the underlying REST API Describe Job in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
        job_id(str): The ID of the job to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.job.init.describe(
                ctx, account_id=value, vault_name=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.job.init.describe account_id=value, vault_name=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="describe_job",
        op_kwargs={"accountId": account_id, "vaultName": vault_name, "jobId": job_id},
    )


async def initiate(
    hub, ctx, account_id: str, vault_name: str, job_parameters: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation initiates a job of the specified type, which can be a select, an archival retrieval, or a vault retrieval. For more information about using this operation, see the documentation for the underlying REST API Initiate a Job.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        job_parameters(Dict, optional): Provides options for specifying job information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.job.init.initiate(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.job.init.initiate account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="initiate_job",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "jobParameters": job_parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    batch_prediction_id: str,
    ml_model_id: str,
    batch_prediction_data_source_id: str,
    output_uri: str,
    batch_prediction_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates predictions for a group of observations. The observations to process exist in one or more data files referenced by a DataSource. This operation creates a new BatchPrediction, and uses an MLModel and the data files referenced by the DataSource as information sources.   CreateBatchPrediction is an asynchronous operation. In response to CreateBatchPrediction, Amazon Machine Learning (Amazon ML) immediately returns and sets the BatchPrediction status to PENDING. After the BatchPrediction completes, Amazon ML sets the status to COMPLETED.  You can poll for status updates by using the GetBatchPrediction operation and checking the Status parameter of the result. After the COMPLETED status appears, the results are available in the location specified by the OutputUri parameter.

    Args:
        batch_prediction_id(str): A user-supplied ID that uniquely identifies the BatchPrediction.
        batch_prediction_name(str, optional): A user-supplied name or description of the BatchPrediction. BatchPredictionName can only use the UTF-8 character set. Defaults to None.
        ml_model_id(str): The ID of the MLModel that will generate predictions for the group of observations. .
        batch_prediction_data_source_id(str): The ID of the DataSource that points to the group of observations to predict.
        output_uri(str): The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'. Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.batch_prediction.create(
                ctx,
                batch_prediction_id=value,
                ml_model_id=value,
                batch_prediction_data_source_id=value,
                output_uri=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.batch_prediction.create batch_prediction_id=value, ml_model_id=value, batch_prediction_data_source_id=value, output_uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="create_batch_prediction",
        op_kwargs={
            "BatchPredictionId": batch_prediction_id,
            "BatchPredictionName": batch_prediction_name,
            "MLModelId": ml_model_id,
            "BatchPredictionDataSourceId": batch_prediction_data_source_id,
            "OutputUri": output_uri,
        },
    )


async def delete(hub, ctx, batch_prediction_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Assigns the DELETED status to a BatchPrediction, rendering it unusable. After using the DeleteBatchPrediction operation, you can use the GetBatchPrediction operation to verify that the status of the BatchPrediction changed to DELETED.  Caution: The result of the DeleteBatchPrediction operation is irreversible.

    Args:
        batch_prediction_id(str): A user-supplied ID that uniquely identifies the BatchPrediction.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.batch_prediction.delete(
                ctx, batch_prediction_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.batch_prediction.delete batch_prediction_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="delete_batch_prediction",
        op_kwargs={"BatchPredictionId": batch_prediction_id},
    )


async def describe_all(
    hub,
    ctx,
    filter_variable: str = None,
    eq: str = None,
    gt: str = None,
    lt: str = None,
    ge: str = None,
    le: str = None,
    ne: str = None,
    prefix: str = None,
    sort_order: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of BatchPrediction operations that match the search criteria in the request.

    Args:
        filter_variable(str, optional): Use one of the following variables to filter a list of BatchPrediction:    CreatedAt - Sets the search criteria to the BatchPrediction creation date.    Status - Sets the search criteria to the BatchPrediction status.    Name - Sets the search criteria to the contents of the BatchPrediction   Name.    IAMUser - Sets the search criteria to the user account that invoked the BatchPrediction creation.    MLModelId - Sets the search criteria to the MLModel used in the BatchPrediction.    DataSourceId - Sets the search criteria to the DataSource used in the BatchPrediction.    DataURI - Sets the search criteria to the data file(s) used in the BatchPrediction. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.  . Defaults to None.
        eq(str, optional): The equal to operator. The BatchPrediction results will have FilterVariable values that exactly match the value specified with EQ. Defaults to None.
        gt(str, optional): The greater than operator. The BatchPrediction results will have FilterVariable values that are greater than the value specified with GT. Defaults to None.
        lt(str, optional): The less than operator. The BatchPrediction results will have FilterVariable values that are less than the value specified with LT. Defaults to None.
        ge(str, optional): The greater than or equal to operator. The BatchPrediction results will have FilterVariable values that are greater than or equal to the value specified with GE. . Defaults to None.
        le(str, optional): The less than or equal to operator. The BatchPrediction results will have FilterVariable values that are less than or equal to the value specified with LE. Defaults to None.
        ne(str, optional): The not equal to operator. The BatchPrediction results will have FilterVariable values not equal to the value specified with NE. Defaults to None.
        prefix(str, optional): A string that is found at the beginning of a variable, such as Name or Id. For example, a Batch Prediction operation could have the Name 2014-09-09-HolidayGiftMailer. To search for this BatchPrediction, select Name for the FilterVariable and any of the following strings for the Prefix:    2014-09   2014-09-09   2014-09-09-Holiday  . Defaults to None.
        sort_order(str, optional): A two-value parameter that determines the sequence of the resulting list of MLModels.    asc - Arranges the list in ascending order (A-Z, 0-9).    dsc - Arranges the list in descending order (Z-A, 9-0).   Results are sorted by FilterVariable. Defaults to None.
        next_token(str, optional): An ID of the page in the paginated results. Defaults to None.
        limit(int, optional): The number of pages of information to include in the result. The range of acceptable values is 1 through 100. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.batch_prediction.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.batch_prediction.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="describe_batch_predictions",
        op_kwargs={
            "FilterVariable": filter_variable,
            "EQ": eq,
            "GT": gt,
            "LT": lt,
            "GE": ge,
            "LE": le,
            "NE": ne,
            "Prefix": prefix,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def get(hub, ctx, batch_prediction_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a BatchPrediction that includes detailed metadata, status, and data file information for a Batch Prediction request.

    Args:
        batch_prediction_id(str): An ID assigned to the BatchPrediction at creation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.batch_prediction.get(
                ctx, batch_prediction_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.batch_prediction.get batch_prediction_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="get_batch_prediction",
        op_kwargs={"BatchPredictionId": batch_prediction_id},
    )


async def update(
    hub, ctx, batch_prediction_id: str, batch_prediction_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the BatchPredictionName of a BatchPrediction. You can use the GetBatchPrediction operation to view the contents of the updated data element.

    Args:
        batch_prediction_id(str): The ID assigned to the BatchPrediction during creation.
        batch_prediction_name(str): A new user-supplied name or description of the BatchPrediction.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.batch_prediction.update(
                ctx, batch_prediction_id=value, batch_prediction_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.batch_prediction.update batch_prediction_id=value, batch_prediction_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="update_batch_prediction",
        op_kwargs={
            "BatchPredictionId": batch_prediction_id,
            "BatchPredictionName": batch_prediction_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    repository_name: str,
    destination_commit_specifier: str,
    source_commit_specifier: str,
    merge_option: str,
    file_path: str,
    max_merge_hunks: int = None,
    conflict_detail_level: str = None,
    conflict_resolution_strategy: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy. If the merge option for the attempted merge is specified as FAST_FORWARD_MERGE, an exception is thrown.

    Args:
        repository_name(str): The name of the repository where you want to get information about a merge conflict.
        destination_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        source_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        merge_option(str): The merge option or strategy you want to use to merge the code.
        max_merge_hunks(int, optional): The maximum number of merge hunks to include in the output. Defaults to None.
        file_path(str): The path of the target files used to describe the conflicts. .
        conflict_detail_level(str, optional): The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line. Defaults to None.
        conflict_resolution_strategy(str, optional): Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.merge.conflict.describe_all(
                ctx,
                repository_name=value,
                destination_commit_specifier=value,
                source_commit_specifier=value,
                merge_option=value,
                file_path=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.merge.conflict.describe_all repository_name=value, destination_commit_specifier=value, source_commit_specifier=value, merge_option=value, file_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="describe_merge_conflicts",
        op_kwargs={
            "repositoryName": repository_name,
            "destinationCommitSpecifier": destination_commit_specifier,
            "sourceCommitSpecifier": source_commit_specifier,
            "mergeOption": merge_option,
            "maxMergeHunks": max_merge_hunks,
            "filePath": file_path,
            "conflictDetailLevel": conflict_detail_level,
            "conflictResolutionStrategy": conflict_resolution_strategy,
            "nextToken": next_token,
        },
    )


async def get_all(
    hub,
    ctx,
    repository_name: str,
    destination_commit_specifier: str,
    source_commit_specifier: str,
    merge_option: str,
    conflict_detail_level: str = None,
    max_conflict_files: int = None,
    conflict_resolution_strategy: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about merge conflicts between the before and after commit IDs for a pull request in a repository.

    Args:
        repository_name(str): The name of the repository where the pull request was created.
        destination_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        source_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        merge_option(str): The merge option or strategy you want to use to merge the code. .
        conflict_detail_level(str, optional): The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line. Defaults to None.
        max_conflict_files(int, optional): The maximum number of files to include in the output. Defaults to None.
        conflict_resolution_strategy(str, optional): Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.merge.conflict.get_all(
                ctx,
                repository_name=value,
                destination_commit_specifier=value,
                source_commit_specifier=value,
                merge_option=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.merge.conflict.get_all repository_name=value, destination_commit_specifier=value, source_commit_specifier=value, merge_option=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_merge_conflicts",
        op_kwargs={
            "repositoryName": repository_name,
            "destinationCommitSpecifier": destination_commit_specifier,
            "sourceCommitSpecifier": source_commit_specifier,
            "mergeOption": merge_option,
            "conflictDetailLevel": conflict_detail_level,
            "maxConflictFiles": max_conflict_files,
            "conflictResolutionStrategy": conflict_resolution_strategy,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, web_acl_id: str, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic Regional documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Associates a web ACL with a resource, either an application load balancer or Amazon API Gateway stage.

    Args:
        web_acl_id(str): A unique identifier (ID) for the web ACL. .
        resource_arn(str): The ARN (Amazon Resource Name) of the resource to be protected, either an application load balancer or Amazon API Gateway stage.  The ARN should be in one of the following formats:   For an Application Load Balancer: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id     For an Amazon API Gateway stage: arn:aws:apigateway:region::/restapis/api-id/stages/stage-name    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.associate(
                ctx, web_acl_id=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.associate web_acl_id=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="associate_web_acl",
        op_kwargs={"WebACLId": web_acl_id, "ResourceArn": resource_arn},
    )


async def create(
    hub,
    ctx,
    name: str,
    metric_name: str,
    default_action: Dict,
    change_token: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a WebACL, which contains the Rules that identify the CloudFront web requests that you want to allow, block, or count. AWS WAF evaluates Rules in order based on the value of Priority for each Rule. You also specify a default action, either ALLOW or BLOCK. If a web request doesn't match any of the Rules in a WebACL, AWS WAF responds to the request with the default action.  To create and configure a WebACL, perform the following steps:   Create and update the ByteMatchSet objects and other predicates that you want to include in Rules. For more information, see CreateByteMatchSet, UpdateByteMatchSet, CreateIPSet, UpdateIPSet, CreateSqlInjectionMatchSet, and UpdateSqlInjectionMatchSet.   Create and update the Rules that you want to include in the WebACL. For more information, see CreateRule and UpdateRule.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateWebACL request.   Submit a CreateWebACL request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateWebACL request.   Submit an UpdateWebACL request to specify the Rules that you want to include in the WebACL, to specify the default action, and to associate the WebACL with a CloudFront distribution.   For more information about how to use the AWS WAF API, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the WebACL. You can't change Name after you create the WebACL.
        metric_name(str): A friendly name or description for the metrics for this WebACL.The name can contain only alphanumeric characters (A-Z, a-z, 0-9), with maximum length 128 and minimum length one. It can't contain whitespace or metric names reserved for AWS WAF, including "All" and "Default_Action." You can't change MetricName after you create the WebACL.
        default_action(Dict): The action that you want AWS WAF to take when a request doesn't match the criteria specified in any of the Rule objects that are associated with the WebACL.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        tags(List, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.create(
                ctx, name=value, metric_name=value, default_action=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.create name=value, metric_name=value, default_action=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_web_acl",
        op_kwargs={
            "Name": name,
            "MetricName": metric_name,
            "DefaultAction": default_action,
            "ChangeToken": change_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, web_acl_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a WebACL. You can't delete a WebACL if it still contains any Rules. To delete a WebACL, perform the following steps:   Update the WebACL to remove Rules, if any. For more information, see UpdateWebACL.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteWebACL request.   Submit a DeleteWebACL request.

    Args:
        web_acl_id(str): The WebACLId of the WebACL that you want to delete. WebACLId is returned by CreateWebACL and by ListWebACLs.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.delete(
                ctx, web_acl_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.delete web_acl_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_web_acl",
        op_kwargs={"WebACLId": web_acl_id, "ChangeToken": change_token},
    )


async def disassociate(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic Regional documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Removes a web ACL from the specified resource, either an application load balancer or Amazon API Gateway stage.

    Args:
        resource_arn(str): The ARN (Amazon Resource Name) of the resource from which the web ACL is being removed, either an application load balancer or Amazon API Gateway stage. The ARN should be in one of the following formats:   For an Application Load Balancer: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id     For an Amazon API Gateway stage: arn:aws:apigateway:region::/restapis/api-id/stages/stage-name    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.disassociate(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.disassociate resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="disassociate_web_acl",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def get(hub, ctx, web_acl_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the WebACL that is specified by WebACLId.

    Args:
        web_acl_id(str): The WebACLId of the WebACL that you want to get. WebACLId is returned by CreateWebACL and by ListWebACLs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.get(ctx, web_acl_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.get web_acl_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_web_acl",
        op_kwargs={"WebACLId": web_acl_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of WebACLSummary objects in the response.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more WebACL objects than the number that you specify for Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of WebACL objects. For the second and subsequent ListWebACLs requests, specify the value of NextMarker from the previous response to get information about another batch of WebACL objects. Defaults to None.
        limit(int, optional): Specifies the number of WebACL objects that you want AWS WAF to return for this request. If you have more WebACL objects than the number that you specify for Limit, the response includes a NextMarker value that you can use to get another batch of WebACL objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_web_acls",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub,
    ctx,
    web_acl_id: str,
    change_token: str,
    updates: List = None,
    default_action: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes ActivatedRule objects in a WebACL. Each Rule identifies web requests that you want to allow, block, or count. When you update a WebACL, you specify the following values:   A default action for the WebACL, either ALLOW or BLOCK. AWS WAF performs the default action if a request doesn't match the criteria in any of the Rules in a WebACL.   The Rules that you want to add or delete. If you want to replace one Rule with another, you delete the existing Rule and add the new one.   For each Rule, whether you want AWS WAF to allow requests, block requests, or count requests that match the conditions in the Rule.   The order in which you want AWS WAF to evaluate the Rules in a WebACL. If you add more than one Rule to a WebACL, AWS WAF evaluates each request against the Rules in order based on the value of Priority. (The Rule that has the lowest value for Priority is evaluated first.) When a web request matches all the predicates (such as ByteMatchSets and IPSets) in a Rule, AWS WAF immediately takes the corresponding action, allow or block, and doesn't evaluate the request against the remaining Rules in the WebACL, if any.    To create and configure a WebACL, perform the following steps:   Create and update the predicates that you want to include in Rules. For more information, see CreateByteMatchSet, UpdateByteMatchSet, CreateIPSet, UpdateIPSet, CreateSqlInjectionMatchSet, and UpdateSqlInjectionMatchSet.   Create and update the Rules that you want to include in the WebACL. For more information, see CreateRule and UpdateRule.   Create a WebACL. See CreateWebACL.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateWebACL request.   Submit an UpdateWebACL request to specify the Rules that you want to include in the WebACL, to specify the default action, and to associate the WebACL with a CloudFront distribution.  The ActivatedRule can be a rule group. If you specify a rule group as your ActivatedRule , you can exclude specific rules from that rule group. If you already have a rule group associated with a web ACL and want to submit an UpdateWebACL request to exclude certain rules from that rule group, you must first remove the rule group from the web ACL, the re-insert it again, specifying the excluded rules. For details, see ActivatedRule$ExcludedRules .    Be aware that if you try to add a RATE_BASED rule to a web ACL without setting the rule type when first creating the rule, the UpdateWebACL request will fail because the request tries to add a REGULAR rule (the default rule type) with the specified ID, which does not exist.  For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        web_acl_id(str): The WebACLId of the WebACL that you want to update. WebACLId is returned by CreateWebACL and by ListWebACLs.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List, optional): An array of updates to make to the WebACL. An array of WebACLUpdate objects that you want to insert into or delete from a WebACL. For more information, see the applicable data types:    WebACLUpdate: Contains Action and ActivatedRule     ActivatedRule: Contains Action, OverrideAction, Priority, RuleId, and Type. ActivatedRule|OverrideAction applies only when updating or adding a RuleGroup to a WebACL. In this case, you do not use ActivatedRule|Action. For all other update requests, ActivatedRule|Action is used instead of ActivatedRule|OverrideAction.     WafAction: Contains Type   . Defaults to None.
        default_action(Dict, optional): A default action for the web ACL, either ALLOW or BLOCK. AWS WAF performs the default action if a request doesn't match the criteria in any of the rules in a web ACL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.init.update(
                ctx, web_acl_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.init.update web_acl_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_web_acl",
        op_kwargs={
            "WebACLId": web_acl_id,
            "ChangeToken": change_token,
            "Updates": updates,
            "DefaultAction": default_action,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    portfolio_id: str,
    principal_arn: str,
    principal_type: str,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified principal ARN with the specified portfolio.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        principal_arn(str): The ARN of the principal (IAM user, role, or group).
        principal_type(str): The principal type. The supported value is IAM.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.principal.with_portfolio.associate(
                ctx, portfolio_id=value, principal_arn=value, principal_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.principal.with_portfolio.associate portfolio_id=value, principal_arn=value, principal_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="associate_principal_with_portfolio",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "PrincipalARN": principal_arn,
            "PrincipalType": principal_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partition_input: Dict,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new partition.

    Args:
        catalog_id(str, optional): The Amazon Web Services account ID of the catalog in which the partition is to be created. Defaults to None.
        database_name(str): The name of the metadata database in which the partition is to be created.
        table_name(str): The name of the metadata table in which the partition is to be created.
        partition_input(Dict): A PartitionInput structure defining the partition to be created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.init.create(
                ctx, database_name=value, table_name=value, partition_input=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.init.create database_name=value, table_name=value, partition_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_partition",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionInput": partition_input,
        },
    )


async def delete(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partition_values: List,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified partition.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the partition to be deleted resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database in which the table in question resides.
        table_name(str): The name of the table that contains the partition to be deleted.
        partition_values(List): The values that define the partition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.init.delete(
                ctx, database_name=value, table_name=value, partition_values=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.init.delete database_name=value, table_name=value, partition_values=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_partition",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionValues": partition_values,
        },
    )


async def get(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partition_values: List,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a specified partition.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the partition in question resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database where the partition resides.
        table_name(str): The name of the partition's table.
        partition_values(List): The values that define the partition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.init.get(
                ctx, database_name=value, table_name=value, partition_values=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.init.get database_name=value, table_name=value, partition_values=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_partition",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionValues": partition_values,
        },
    )


async def get_all(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    catalog_id: str = None,
    expression: str = None,
    next_token: str = None,
    segment: Dict = None,
    max_results: int = None,
    exclude_column_schema: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the partitions in a table.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the partitions in question reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database where the partitions reside.
        table_name(str): The name of the partitions' table.
        expression(str, optional): An expression that filters the partitions to be returned. The expression uses SQL syntax similar to the SQL WHERE filter clause. The SQL statement parser JSQLParser parses the expression.   Operators: The following are the operators that you can use in the Expression API call:  =  Checks whether the values of the two operands are equal; if yes, then the condition becomes true. Example: Assume 'variable a' holds 10 and 'variable b' holds 20.  (a = b) is not true.  < >  Checks whether the values of two operands are equal; if the values are not equal, then the condition becomes true. Example: (a < > b) is true.  >  Checks whether the value of the left operand is greater than the value of the right operand; if yes, then the condition becomes true. Example: (a > b) is not true.  <  Checks whether the value of the left operand is less than the value of the right operand; if yes, then the condition becomes true. Example: (a < b) is true.  >=  Checks whether the value of the left operand is greater than or equal to the value of the right operand; if yes, then the condition becomes true. Example: (a >= b) is not true.  <=  Checks whether the value of the left operand is less than or equal to the value of the right operand; if yes, then the condition becomes true. Example: (a <= b) is true.  AND, OR, IN, BETWEEN, LIKE, NOT, IS NULL  Logical operators.    Supported Partition Key Types: The following are the supported partition keys.    string     date     timestamp     int     bigint     long     tinyint     smallint     decimal    If an type is encountered that is not valid, an exception is thrown.  The following list shows the valid operators on each type. When you define a crawler, the partitionKey type is created as a STRING, to be compatible with the catalog partitions.   Sample API Call: . Defaults to None.
        next_token(str, optional): A continuation token, if this is not the first call to retrieve these partitions. Defaults to None.
        segment(Dict, optional): The segment of the table's partitions to scan in this request. Defaults to None.
        max_results(int, optional): The maximum number of partitions to return in a single response. Defaults to None.
        exclude_column_schema(bool, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.init.get_all(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.init.get_all database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_partitions",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "Expression": expression,
            "NextToken": next_token,
            "Segment": segment,
            "MaxResults": max_results,
            "ExcludeColumnSchema": exclude_column_schema,
        },
    )


async def update(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partition_value_list: List,
    partition_input: Dict,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a partition.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the partition to be updated resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database in which the table in question resides.
        table_name(str): The name of the table in which the partition to be updated is located.
        partition_value_list(List): List of partition key values that define the partition to update.
        partition_input(Dict): The new partition object to update the partition to. The Values property can't be changed. If you want to change the partition key values for a partition, delete and recreate the partition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.init.update(
                ctx,
                database_name=value,
                table_name=value,
                partition_value_list=value,
                partition_input=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.init.update database_name=value, table_name=value, partition_value_list=value, partition_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_partition",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionValueList": partition_value_list,
            "PartitionInput": partition_input,
        },
    )
